import { useEffect, useState } from "react"
import Taro from "@tarojs/taro"
import { View, ScrollView } from "@tarojs/components"
import CustomNav from "@/components/CustomNav"
import withLayout from '@/layouts'
import { getMachineryList } from '@/services/machinery'
import { useModel } from "@/store"
import MachineryCard from './Card'
import './style.less'

export default withLayout((props) => {
  const { location } = useModel('location')
  const [machinery, setMachinery] = useState([])
  const goDetail = (val) => {
    Taro.navigateTo({ url: `/pages/machineryDetail/index?id=${val}` });
  }
  const goMap = () => {
    Taro.navigateTo({ url: '/pages/machineryMap/index' });
  }
  useEffect(() => {
    getMachineryList({ location: location }).then((res) => {
      setMachinery(res.records)
    })
  }, [])
  return (
    <View className='page-index'>
      <View className='index-navbar'>
        <CustomNav title='农机列表' />
      </View>
      <View className='index-container machineryListContent'>
        <ScrollView scrollY style={{ height: '100%' }}>
          {
            machinery?.map((item) => {
              return <MachineryCard value={item} onClick={() => goDetail(item.machineryId)} goMap={() => goMap()} />
            })
          }
        </ScrollView>
      </View>
    </View>
  )
})
